# virtualenv

turn the current directory into a virtualenv

    virtualenv .


activate a virtualenv that has been created in the current directory

    source bin/activate


exit a virtualenv

    deactivate


create a virtualenv in the current directory with a particular python version

    virtualenv -p /path/to/python/executable .



# Basic Usage

Create a virtualenv in a directory:

    virtualenv <directory>


Activate a virtualenv:

    source <virtualenv/dir>/bin/activate


Exit a virtualenv that has been activated:

    deactivate


Print complete virtualenv help (`-h`):

    virtualenv -h


